pub struct Clock;Expand description
Global clock access - like Utc::now() but testable.
Implementations
Sourceimpl Clock
impl Clock
Sourcepub fn now() -> DateTime<Utc>
pub fn now() -> DateTime<Utc>
Get current time from the global clock.
Lazily initializes to realtime if not already set.
Sourcepub fn today() -> NaiveDate
pub fn today() -> NaiveDate
Get the current date (without time component).
Lazily initializes to realtime if not already set.
Sourcepub fn sleep(duration: Duration) -> ClockSleep ⓘ
pub fn sleep(duration: Duration) -> ClockSleep ⓘ
Sleep using the global clock.
Sourcepub fn timeout<F: Future>(duration: Duration, future: F) -> ClockTimeout<F> ⓘ
pub fn timeout<F: Future>(duration: Duration, future: F) -> ClockTimeout<F> ⓘ
Timeout using the global clock.
Sourcepub fn handle() -> &'static ClockHandle
pub fn handle() -> &'static ClockHandle
Get a reference to the global clock handle.
Sourcepub fn install_manual() -> ClockController
pub fn install_manual() -> ClockController
Install a manual clock globally.
- If not initialized: installs manual clock, returns controller
- If already manual: returns existing controller (idempotent)
- If already realtime: panics
Must be called before any Clock::now() calls if you want manual time.
Sourcepub fn install_manual_at(start_at: DateTime<Utc>) -> ClockController
pub fn install_manual_at(start_at: DateTime<Utc>) -> ClockController
Install a manual clock globally starting at a specific time.
See install_manual for details.
Sourcepub fn manual_now() -> Option<DateTime<Utc>>
pub fn manual_now() -> Option<DateTime<Utc>>
Get the current manual time, if a manual clock is installed.
Returns:
Noneif no clock is initialized (doesn’t initialize one)Nonefor realtime clocksSome(time)for manual clocks