#[non_exhaustive]pub enum FatalKind {
Invariant,
Config,
CorruptState,
Dependency,
Panic,
Exhausted,
Denied,
}Expand description
Why a Fatal outcome is a bug, a misconfiguration, or corrupt state.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Invariant
Config
CorruptState
Dependency
Panic
Exhausted
Denied
A Denied narrowed at a boundary with no subject to deny — code
running as the system. The Denied is the source. Mirrors
Exhausted: just as the struct Exhausted is the source of a
Fatal(Exhausted), the struct Denied is the source of a
Fatal(Denied).
Implementations