pub struct OneTimeExecutor<'c, E>{ /* private fields */ }Expand description
A struct that owns an sqlx::Executor.
Calling one of the fetch_ fns will consume it
thus garuanteeing a 1 time usage.
It is not used directly but passed via the IntoOneTimeExecutor trait.
In order to make the consumption of the executor work we have to pass the query to the executor:
async fn query(ex: impl es_entity::IntoOneTimeExecutor<'_>) -> Result<(), sqlx::Error> {
ex.into_executor().fetch_optional(
sqlx::query!(
"SELECT NOW()"
)
).await?;
Ok(())
}Implementations
Sourceimpl<'c, E> OneTimeExecutor<'c, E>
impl<'c, E> OneTimeExecutor<'c, E>
pub fn maybe_now(&self) -> Option<DateTime<Utc>>
Sourcepub async fn fetch_one<'q, F, O, A>(
self,
query: Map<'q, Db, F, A>,
) -> Result<O, Error>
pub async fn fetch_one<'q, F, O, A>( self, query: Map<'q, Db, F, A>, ) -> Result<O, Error>
Proxy call to query.fetch_one but guarantees the inner executor will only be used once.
Sourcepub async fn fetch_all<'q, F, O, A>(
self,
query: Map<'q, Postgres, F, A>,
) -> Result<Vec<O>, Error>
pub async fn fetch_all<'q, F, O, A>( self, query: Map<'q, Postgres, F, A>, ) -> Result<Vec<O>, Error>
Proxy call to query.fetch_all but guarantees the inner executor will only be used once.