OpWithTime

Struct OpWithTime 

pub struct OpWithTime<'a, Op: AtomicOperation + ?Sized> { /* private fields */ }
Wrapper that guarantees time is available, borrowing the underlying operation.

Implementations

Source

impl<'a, Op: AtomicOperation + ?Sized> OpWithTime<'a, Op>

pub async fn cached_or_db_time(op: &'a mut Op) -> Result<Self, Error>

Wraps an operation, using existing time if present, otherwise fetching from DB.

Priority order:

  1. Cached time from operation
  2. Manual clock time if the operation’s clock is manual
  3. Database time via SELECT NOW()
pub fn cached_or_time(op: &'a mut Op, time: DateTime<Utc>) -> Self

Wraps with a specific time (uses existing if present).

pub fn cached_or_clock_time(op: &'a mut Op) -> Self

Wraps using system time (uses existing if present).

Uses cached time if present, otherwise uses the operation’s clock.

pub fn now(&self) -> DateTime<Utc>