Module pagination

Module pagination 

Control and customize the query execution and its response.

Structs

PaginatedQueryArgs
A cursor-based pagination structure for efficiently paginating through large datasets
PaginatedQueryRet
Return type for paginated queries containing entities and pagination metadata
Sort
Structure to sort entities on a specific field when listing from database

Enums

ListDirection
Controls the sorting order when listing the entities from the database