pub struct Continuation<C> {
pub after: C,
pub first: usize,
}Expand description
A continuation to the next page, carrying the cursor it resumes from.
Unlike PaginatedQueryArgs, whose cursor is optional because a query may
start from the beginning, a continuation always has one.
Fields
after: Cfirst: usizeTrait Implementations
Sourceimpl<C: Debug> Debug for Continuation<C>
impl<C: Debug> Debug for Continuation<C>
Sourceimpl<C> From<Continuation<C>> for PaginatedQueryArgs<C>
impl<C> From<Continuation<C>> for PaginatedQueryArgs<C>
Sourcefn from(continuation: Continuation<C>) -> Self
fn from(continuation: Continuation<C>) -> Self
Converts to this type from the input type.