pub trait IntoOneTimeExecutorAt<'c> {
type Executor: Executor<'c, Database = Db>;
// Required method
fn into_executor(self) -> OneTimeExecutor<'c, Self::Executor>
where Self: 'c;
}Expand description
A trait to signify that we can use an argument for 1 round trip to the database
Auto implemented on all &mut AtomicOperation types and
&db::Pool.
Required Associated Types
Required Methods
Sourcefn into_executor(self) -> OneTimeExecutor<'c, Self::Executor>where
Self: 'c,
fn into_executor(self) -> OneTimeExecutor<'c, Self::Executor>where
Self: 'c,
Transforms into a OneTimeExecutor which can be used to execute a round trip.