Module operation

Module operation 

Handle execution of database operations and transactions.

Modules

hooks
Commit hooks for executing custom logic before and after transaction commits.

Structs

DbOp
Default return type of the derived EsRepo::begin_op().
DbOpWithTime
Equivileant of DbOp just that the time is guaranteed to be cached.
HookSlot
Where a released SavepointOp’s staged commit hooks fold into.
OpWithTime
Wrapper that guarantees time is available, borrowing the underlying operation.
SavepointOp
An AtomicOperation scoped to a database SAVEPOINT inside a parent DbOp or another SavepointOp.

Traits

AtomicOperation
Trait to signify we can make multiple consistent database roundtrips.
AtomicOperationWithTime
SavepointOperation
Savepoints for every AtomicOperation, derived rather than hand-written.
WrapsOperation
Derives the whole of AtomicOperation for a type that wraps another operation, by delegation.