pub struct OpWithTime<'a, Op: AtomicOperation + ?Sized> { /* private fields */ }Expand description
Wrapper that guarantees time is available, borrowing the underlying operation.
Implementations
Sourceimpl<'a, Op: AtomicOperation + ?Sized> OpWithTime<'a, Op>
impl<'a, Op: AtomicOperation + ?Sized> OpWithTime<'a, Op>
Sourcepub async fn cached_or_db_time(op: &'a mut Op) -> Result<Self, Error>
pub async fn cached_or_db_time(op: &'a mut Op) -> Result<Self, Error>
Wraps an operation, using existing time if present, otherwise fetching from DB.
Priority order:
- Cached time from operation
- Manual clock time if the operation’s clock is manual
- Database time via
SELECT NOW()
Sourcepub fn cached_or_time(op: &'a mut Op, time: DateTime<Utc>) -> Self
pub fn cached_or_time(op: &'a mut Op, time: DateTime<Utc>) -> Self
Wraps with a specific time (uses existing if present).
Sourcepub fn cached_or_clock_time(op: &'a mut Op) -> Self
pub fn cached_or_clock_time(op: &'a mut Op) -> Self
Wraps using system time (uses existing if present).
Uses cached time if present, otherwise uses the operation’s clock.
pub fn now(&self) -> DateTime<Utc>