Control and customize the query execution and its response.
Structs
- Paginated
Query Args - A cursor-based pagination structure for efficiently paginating through large datasets
- Paginated
Query Ret - Return type for paginated queries containing entities and pagination metadata
- Sort
- Structure to sort entities on a specific field when listing from database
Enums
- List
Direction - Controls the sorting order when listing the entities from the database