pub struct DbOp<'c> { /* private fields */ }Expand description
Default return type of the derived EsRepo::begin_op().
Used as a wrapper of a sqlx::Transaction but can also cache the time at which the
transaction is taking place.
When a manual clock is provided, the transaction will automatically cache that clock’s time, enabling deterministic testing. This cached time will be used in all time-dependent operations.
Implementations
Sourceimpl<'c> DbOp<'c>
impl<'c> DbOp<'c>
Sourcepub async fn init(pool: &Pool) -> Result<DbOp<'static>, Error>
pub async fn init(pool: &Pool) -> Result<DbOp<'static>, Error>
Initializes a transaction using the global clock.
Delegates to init_with_clock using the global clock handle.
Sourcepub async fn init_with_clock(
pool: &Pool,
clock: &ClockHandle,
) -> Result<DbOp<'static>, Error>
pub async fn init_with_clock( pool: &Pool, clock: &ClockHandle, ) -> Result<DbOp<'static>, Error>
Initializes a transaction with the specified clock.
If the clock is manual, its current time will be cached in the transaction.
Sourcepub fn with_time(self, time: DateTime<Utc>) -> DbOpWithTime<'c>
pub fn with_time(self, time: DateTime<Utc>) -> DbOpWithTime<'c>
Transitions to a DbOpWithTime with the given time cached.
Sourcepub fn with_clock_time(self) -> DbOpWithTime<'c>
pub fn with_clock_time(self) -> DbOpWithTime<'c>
Transitions to a DbOpWithTime using the clock.
Uses cached time if present, otherwise uses the clock’s current time.
Sourcepub async fn with_db_time(self) -> Result<DbOpWithTime<'c>, Error>
pub async fn with_db_time(self) -> Result<DbOpWithTime<'c>, Error>
Transitions to a DbOpWithTime using the database time.
Priority order:
- Cached time if present
- Manual clock time if the clock is manual
- Database time via
SELECT NOW()
Sourcepub fn maybe_now(&self) -> Option<DateTime<Utc>>
pub fn maybe_now(&self) -> Option<DateTime<Utc>>
Returns the optionally cached chrono::DateTime
Sourcepub fn tx_mut(&mut self) -> &mut Transaction<'c, Db>
pub fn tx_mut(&mut self) -> &mut Transaction<'c, Db>
Gets a mutable handle to the inner transaction